@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-bookmark-in-project
 ;; Keywords: convenience
-;; Package-Version: 20251016.2129
-;; Package-Revision: a7321494355e
+;; Package-Version: 20251126.519
+;; Package-Revision: 9602be7da3fb
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -116,7 +116,7 @@ where the first argument is always ELEMENT, the second is a member of XS."
   (declare (important-return-value t))
   (let ((index 0)
         (test-fn (or (plist-get args :test) #'equal)))
-    (while (and xs (not (funcall test-fn element (car xs))))
+    (while (and xs (null (funcall test-fn element (car xs))))
       (incf index)
       (setq xs (cdr xs)))
     (and xs index)))
@@ -130,7 +130,7 @@ where the first argument is always ELEMENT, the second is a member of XS."
   (let ((xs-length (length xs))
         (index 0)
         (test-fn (or (plist-get args :test) #'equal)))
-    (while (and (< index xs-length) (not (funcall test-fn element (aref xs index))))
+    (while (and (< index xs-length) (null (funcall test-fn element (aref xs index))))
       (incf index))
     (and (< index xs-length) index)))
 
